## 1. Specs

- [x] 1.1 Add a provider-management requirement that Platform fallback uses the primary and secondary remaining-percent thresholds.

## 2. Implementation

- [x] 2.1 Route Platform fallback using `primary_remaining_percent <= 10` and `secondary_remaining_percent <= 5`.

## 3. Verification

- [x] 3.1 Run fallback-related proxy tests without modifying test code.
